==> haskell-bower-json-1.0.0.1-96-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-BbtJUdl5cTvJbwv7m6gx5i
key: bower-json-1.0.0.1-BbtJUdl5cTvJbwv7m6gx5i
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: a6f08cf0c349073b6d8366528e957952
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-BbtJUdl5cTvJbwv7m6gx5i
depends:
    aeson-1.4.2.0-3zTMwffMFEmL8PGGMXbXzR
    aeson-better-errors-0.9.1.0-F9MCIKKd52jJQeLXpteglj base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bower-json-1.0.0.1-99-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bower-json.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bower-json
version: 1.0.0.1
id: bower-json-1.0.0.1-GWfeTkgH5j01r0pIyuWnG8
key: bower-json-1.0.0.1-GWfeTkgH5j01r0pIyuWnG8
license: MIT
maintainer: harry@garrood.me
author: Harry Garrood
homepage: https://github.com/hdgarrood/bower-json
synopsis: Read bower.json from Haskell
description:
    Bower is a package manager for the web (see <http://bower.io>).
    This package provides a data type and ToJSON/FromJSON instances for Bower'\''s
    package manifest file, bower.json.
category: Web
abi: ae202dc2ab70e2e93c84cee0b0015d3b
exposed: True
exposed-modules:
    Web.Bower.PackageMeta
hidden-modules: Web.Bower.PackageMeta.Internal
import-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
library-dirs: /usr/lib/ghc-8.6.3/site-local/bower-json-1.0.0.1
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.3/bower-json-1.0.0.1
hs-libraries: HSbower-json-1.0.0.1-GWfeTkgH5j01r0pIyuWnG8
depends:
    aeson-1.4.2.0-GJCiFec4f867wIRLCAWvTv
    aeson-better-errors-0.9.1.0-4RFAouByPAqC9nGPwgWbwE base-4.12.0.0
    bytestring-0.10.8.2 deepseq-1.4.4.0 ghc-prim-0.5.3 mtl-2.2.2
    scientific-0.3.6.2-9lkO4JSfZDD3N7SSlCrzCi text-1.2.3.1
    transformers-0.5.5.0
    unordered-containers-0.2.10.0-6u5qZnIDidK2MmAyNc87rJ
    vector-0.12.0.2-5G85DK6NPIx1LphnqJy7eO
haddock-interfaces: /usr/share/doc/haskell-bower-json/html/bower-json.haddock
haddock-html: /usr/share/doc/haskell-bower-json/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
